Skip to contents

A dataset containing population information for the Short Creek area (Hildale city, Utah, Colorado City town, Arizona, and Centennial Park, Arizona) organized by age groups.

Usage

short_creek

Format

A data frame with 15 rows and 4 columns:

age_labels

character. Labels describing the age groups.

agepops

numeric. Population counts for each age group.

agelims

numeric. Age limit boundaries for each group.

vacc_rate

numeric. Vaccination rate for each age group.

The data was generated using the multigroup.vaccine R package: Toth D (2025). multigroup.vaccine: Multigroup Vaccine Model. R package version 0.1.0, commit 3047ebf568c9b2028336dc14af587a282de9e225, https://github.com/EpiForeSITE/multigroup-vaccine. The source code is available at https://github.com/UofUEpiBio/measles

Details

This dataset provides demographic information for the Short Creek area (Hildale city, Utah, Colorado City town, Arizona, and Centenial Park, Arizona), with population data disaggregated by 15 age categories. This dataset matches the short_creek_matrix matrix.

This data uses real vaccination rates from publicly available school records, and population age structure and composition from the latest US census. Vaccination rates for the non-school-aged population were imputed based on assumptions and do not reflect the actual vaccination information for those age groups.

Examples

data(short_creek)
head(short_creek)
#>   age_labels agepops agelims vacc_rate
#> 1     under1     113       1 0.0000000
#> 2       1to4     450       4 0.2355556
#> 3    5to11s1     281      11 0.0569395
#> 4    5to11s2     393      11 0.3180662
#> 5    5to11s3     213      11 0.3661972
#> 6   12to13s4      85      13 0.2235294