Skip to contents

Create a measles post-exposure prophylaxis (PEP) intervention

Usage

InterventionMeaslesPEP(
  name,
  mmr_efficacy,
  ig_efficacy,
  ig_half_life_mean,
  ig_half_life_sd,
  mmr_willingness,
  ig_willingness,
  mmr_window,
  ig_window,
  target_states,
  states_if_pep_effective,
  states_if_pep_ineffective
)

Arguments

name

Name of the intervention.

mmr_efficacy

Probability of MMR vaccine efficacy.

ig_efficacy

Probability of immunoglobulin (IG) efficacy.

ig_half_life_mean

Mean of the half-life of immunoglobulin (IG) in days.

ig_half_life_sd

Standard deviation of the half-life of immunoglobulin (IG) in days.

mmr_willingness

Probability that an individual will accept MMR vaccine.

ig_willingness

Probability that an individual will accept immunoglobulin (IG).

mmr_window

Time window for MMR vaccine administration.

ig_window

Time window for immunoglobulin (IG) administration.

target_states, states_if_pep_effective, states_if_pep_ineffective

Integer vectors of target and destination states (see details).

Value

An object of class epiworld_globalevent representing the measles PEP intervention.

Details

This functions creates a global event that represents a post-exposure prophylaxis (PEP) intervention for measles. The intervention includes the administration of MMR vaccine and immunoglobulin (IG) to individuals after exposure to the virus, with the goal of reducing the probability of infection and preventing the spread of the disease.

The process involves both PEP Measles-Mumps-Rubella (MMR) vaccine and immunoglobulin (IG). The system decides which agent gets MMR or IG based on the time since exposure and the willingness to accept PEP. The flow is the following:

  1. Agents in target_states are eligible for PEP if they are willing to accept it (based on pep_willingness).

  2. If the agent is already infected (for example, in a latent state) for at most mmr_window days, they are offered MMR vaccine. Otherwise, they are offered IG.

  3. Susceptible agents are offered the MMR vaccine, and if they accept, they are automatically moved out of the quarantine process.

  4. Agents who were already infected and got either MMR or IG may move out of the quarantine process if the PEP is effective (based on mmr_efficacy or ig_efficacy). The destination state depends on whether the PEP was effective or not, and is determined by states_if_pep_effective and states_if_pep_ineffective, respectively.

Since IG winds down over time, the IG "tool" may be removed from the agent as a function of the half-life of IG (based on ig_half_life_mean and ig_half_life_sd). Particularly, after applied, the IG "tool" will have a random duration based on a normal distribution with mean ig_half_life_mean and standard deviation ig_half_life_sd. Once the duration is over, the IG "tool" is removed from the agent, and they are again eligible for PEP if they are exposed again.