A matrix containing spatial data for the Short Creek area (Hildale city, Utah, Colorado City town, Arizona, and Centenial Park, Arizona). The matrix provides an estimate of the mixing rates between schools and the rest of the population in the area.
The data was generated using the multigroup.vaccine R package:
Toth D (2025). multigroup.vaccine: Multigroup Vaccine Model. R
package version 0.1.0, commit 3047ebf568c9b2028336dc14af587a282de9e225,
https://github.com/EpiForeSITE/multigroup-vaccine. The source code
is available at https://github.com/UofUEpiBio/measles